==> dpay_flutter-1.4.12.tar.gz: ios/Classes/SwiftDpayFlutterPlugin.swift <==
import Flutter
import UIKit
import WebKit
import DpaySDK

public class SwiftDpayFlutterPlugin: NSObject, FlutterPlugin {
    
    var delegate : FlutterDpayPluginDelegate
    
    public override init() {
        delegate = FlutterDpayPluginDelegate()
    }
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        print("registered the method channels")
        let channel = FlutterMethodChannel(name: "dpay_flutter", binaryMessenger: registrar.messenger())
        let instance = SwiftDpayFlutterPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }

    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        switch call.method {
            case "openCheckout":
                // let options = call.arguments as! Dictionary<String, Any>
                print("method call function")
                self.delegate.openDpayDelegate(call, result: result)
            default:
                print("no method")
        }
    }
}

public class FlutterDpayPluginDelegate : NSObject, WKNavigationDelegate, DpayCheckoutProtocol {
    
    public var flutterResult: FlutterResult!

    //callback for a successful transaction
    public func onSuccess(transactionResponse: DPaymentSuccess) {
        NSLog("success ios flutter\n" + transactionResponse.response.paymentId)

        let jsonEncoder = JSONEncoder()
        do {
            let encodeTransactionResponse = try jsonEncoder.encode(transactionResponse)
            let paymentSuccess = String(data: encodeTransactionResponse, encoding: .utf8)!
            self.flutterResult(paymentSuccess)
        } catch {
            print(error.localizedDescription)
        }
    }
    
    //callback for a failed transaction
    public func onFailure(transactionResponse: DPaymentFailed) {
        NSLog("failed ios flutter\n" + transactionResponse.response.paymentId)

        let jsonEncoder = JSONEncoder()
        do {
            let encodeTransactionResponse = try jsonEncoder.encode(transactionResponse)
            let paymentFailed = String(data: encodeTransactionResponse, encoding: .utf8)!
            self.flutterResult(paymentFailed)
        } catch {
            print(error.localizedDescription)
        }
    }
    
    //callback for when transaction is closed
    public func onClose(transactionResponse: String) {
        NSLog("close ios flutter\n" + transactionResponse)
        self.flutterResult(transactionResponse)
    }
    
    //get options and open checkout page on main thread
    public func openDpayDelegate(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        let options = call.arguments as! NSMutableDictionary
        let checkoutOptions = DCheckoutOptions()
        buildCheckoutOptions(options: options, checkoutOptions: checkoutOptions)
        DispatchQueue.main.async {
            let dpay = DpaySDK.getInstance
            dpay.checkout(options: checkoutOptions, listener: self)
        }
        self.flutterResult = result
    }

    /*
     function to build the checkout options data class to open the checout page
     params:
        options - Dictionary that is sent from flutter native which contains all the options
        checkoutOptions - Data class with all the checkout options
     */
    func buildCheckoutOptions(options: NSMutableDictionary, checkoutOptions: DCheckoutOptions) {
        
        checkoutOptions.locale = getCheckoutOptions(options: options, key: "locale")
        checkoutOptions.environment = getCheckoutOptions(options: options, key: "environment")
        checkoutOptions.customerId = getCheckoutOptions(options: options, key: "customerId")
        checkoutOptions.siteName = getCheckoutOptions(options: options, key: "siteName")
        checkoutOptions.customerEmail = getCheckoutOptions(options: options, key: "customerEmail")
        checkoutOptions.accessToken = getCheckoutOptions(options: options, key: "accessToken")
        checkoutOptions.orderId = getCheckoutOptions(options: options, key: "orderId")
        checkoutOptions.amount = getCheckoutOptions(options: options, key: "amount")
        checkoutOptions.currency = getCheckoutOptions(options: options, key: "currency")
        checkoutOptions.paymentType = getCheckoutOptions(options: options, key: "paymentType")
        
        checkoutOptions.accentColor = getCheckoutOptions(options: options, key: "accentColor")
        checkoutOptions.themeColor = getCheckoutOptions(options: options, key: "themeColor")
        checkoutOptions.customerGivenName = getCheckoutOptions(options: options, key: "customerGivenName")
        checkoutOptions.customerMobile = getCheckoutOptions(options: options, key: "customerMobile")
        checkoutOptions.customerCountry = getCheckoutOptions(options: options, key: "customerCountry")
        checkoutOptions.customerCity = getCheckoutOptions(options: options, key: "customerCity")
        checkoutOptions.customerRegion = getCheckoutOptions(options: options, key: "customerRegion")
        checkoutOptions.customerAddressLine1 = getCheckoutOptions(options: options, key: "customerAddressLine1")
        checkoutOptions.customerAddressLine2 = getCheckoutOptions(options: options, key: "customerAddressLine2")
        checkoutOptions.customerPostalCode = getCheckoutOptions(options: options, key: "customerPostalCode")
        checkoutOptions.label = getCheckoutOptions(options: options, key: "label")
        checkoutOptions.receiverName = getCheckoutOptions(options: options, key: "receiverName")
        checkoutOptions.receiverPhone = getCheckoutOptions(options: options, key: "receiverPhone")
        checkoutOptions.landmark = getCheckoutOptions(options: options, key: "landmark")
    }
}

==> dpay_flutter-2.0.2.tar.gz: ios/Classes/SwiftDpayFlutterPlugin.swift <==
import Flutter
import UIKit
import WebKit
import DpaySDK

public class SwiftDpayFlutterPlugin: NSObject, FlutterPlugin {
    
    var delegate : FlutterDpayPluginDelegate
    
    public override init() {
        delegate = FlutterDpayPluginDelegate()
    }
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        print("registered the method channels")
        let channel = FlutterMethodChannel(name: "dpay_flutter", binaryMessenger: registrar.messenger())
        let instance = SwiftDpayFlutterPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }

    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        switch call.method {
            case "openCheckout":
                // let options = call.arguments as! Dictionary<String, Any>
                print("method call function")
                self.delegate.openDpayDelegate(call, result: result)
            default:
                print("no method")
        }
    }
}

public class FlutterDpayPluginDelegate : NSObject, WKNavigationDelegate, DpayCheckoutProtocol {
    
    public var flutterResult: FlutterResult!

    //callback for a successful transaction
    public func onSuccess(transactionResponse: DPaymentSuccess) {
        //NSLog("success ios flutter\n" + transactionResponse.response.paymentId)

        let jsonEncoder = JSONEncoder()
        do {
            let encodeTransactionResponse = try jsonEncoder.encode(transactionResponse)
            let paymentSuccess = String(data: encodeTransactionResponse, encoding: .utf8)!
            self.flutterResult(paymentSuccess)
        } catch {
            print(error.localizedDescription)
        }
    }
    
    //callback for a failed transaction
    public func onFailure(transactionResponse: DPaymentFailed) {
        //NSLog("failed ios flutter\n" + transactionResponse.response.paymentId)

        let jsonEncoder = JSONEncoder()
        do {
            let encodeTransactionResponse = try jsonEncoder.encode(transactionResponse)
            let paymentFailed = String(data: encodeTransactionResponse, encoding: .utf8)!
            self.flutterResult(paymentFailed)
        } catch {
            print(error.localizedDescription)
        }
    }
    
    //callback for when transaction is closed
    public func onClose(transactionResponse: String) {
        NSLog("close ios flutter\n" + transactionResponse)
        self.flutterResult(transactionResponse)
    }
    
    //get options and open checkout page on main thread
    public func openDpayDelegate(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        let options = call.arguments as! NSMutableDictionary
        let checkoutOptions = DCheckoutOptions()
        buildCheckoutOptions(options: options, checkoutOptions: checkoutOptions)
        DispatchQueue.main.async {
            let dpay = DpaySDK.getInstance
            dpay.checkout(options: checkoutOptions, listener: self)
        }
        self.flutterResult = result
    }

    /*
     function to build the checkout options data class to open the checout page
     params:
        options - Dictionary that is sent from flutter native which contains all the options
        checkoutOptions - Data class with all the checkout options
     */
    func buildCheckoutOptions(options: NSMutableDictionary, checkoutOptions: DCheckoutOptions) {
        
        checkoutOptions.locale = getCheckoutOptions(options: options, key: "locale")
        checkoutOptions.environment = getCheckoutOptions(options: options, key: "environment")
        checkoutOptions.customerId = getCheckoutOptions(options: options, key: "customerId")
        checkoutOptions.siteName = getCheckoutOptions(options: options, key: "siteName")
        checkoutOptions.customerEmail = getCheckoutOptions(options: options, key: "customerEmail")
        checkoutOptions.accessToken = getCheckoutOptions(options: options, key: "accessToken")
        checkoutOptions.orderId = getCheckoutOptions(options: options, key: "orderId")
        checkoutOptions.amount = getCheckoutOptions(options: options, key: "amount")
        checkoutOptions.currency = getCheckoutOptions(options: options, key: "currency")
        checkoutOptions.paymentType = getCheckoutOptions(options: options, key: "paymentType")
        
        checkoutOptions.accentColor = getCheckoutOptions(options: options, key: "accentColor")
        checkoutOptions.themeColor = getCheckoutOptions(options: options, key: "themeColor")
        checkoutOptions.customerGivenName = getCheckoutOptions(options: options, key: "customerGivenName")
        checkoutOptions.customerMobile = getCheckoutOptions(options: options, key: "customerMobile")
        checkoutOptions.customerCountry = getCheckoutOptions(options: options, key: "customerCountry")
        checkoutOptions.customerCity = getCheckoutOptions(options: options, key: "customerCity")
        checkoutOptions.customerRegion = getCheckoutOptions(options: options, key: "customerRegion")
        checkoutOptions.customerAddressLine1 = getCheckoutOptions(options: options, key: "customerAddressLine1")
        checkoutOptions.customerAddressLine2 = getCheckoutOptions(options: options, key: "customerAddressLine2")
        checkoutOptions.customerPostalCode = getCheckoutOptions(options: options, key: "customerPostalCode")
        checkoutOptions.label = getCheckoutOptions(options: options, key: "label")
        checkoutOptions.receiverName = getCheckoutOptions(options: options, key: "receiverName")
        checkoutOptions.receiverPhone = getCheckoutOptions(options: options, key: "receiverPhone")
        checkoutOptions.landmark = getCheckoutOptions(options: options, key: "landmark")
    }
}
